Learn R Programming

kequate (version 1.5.0)

FTres: Freeman-Tukey Residuals

Description

Calculates the Freeman-Tukey residuals for log-linear models of frequency data. If the frequencies are assumed to be Poisson distributed, then the Freeman-Tukey residuals are approximately normal distributed.

Usage

FTres(obs, fit)

Arguments

obs
A numeric vector containing the observed frequencies.
fit
A numeric vector containing the estimated frequencies.

Value

A numeric vector containing the Freeman-Tukey residuals.

Details

For an observed frequency $ni$ and the estimated frequency $mi$, the Freeman-Tukey residual $FTi$ is defined as $FTi = \sqrt(ni)+\sqrt(ni+1)-\sqrt(4mi+1).$

References

Andersson, B., Branberg, K., Wiberg, M. (2013). Performing the Kernel Method of Test Equating with the Package kequate. Journal of Statistical Software, 55(6), 1--25. URL http://www.jstatsoft.org/v55/i06/

Holland, P.W, Thayer, D. (1998). Univariate and Bivariate Loglinear Models for Discrete Test Score Distributions ETS Technical Report No 98-1.

See Also

glm

Examples

Run this code
#Example data:
P<-c(5, 20, 35, 25, 15)
x<-0:4
glmx<-glm(P~I(x)+I(x^2), family="poisson", x=TRUE)
res<-FTres(glmx$y, glmx$fitted.values)

Run the code above in your browser using DataLab