Learn R Programming

kequate (version 1.5.0)

getEq: Retrieve Equated Values

Description

Function to retrieve the equated values from an object of class keout created by kequate.

Usage

getEq(object)

Arguments

object
An object of class keout as created by the function kequate.

Value

A numeric vector with the equated values.

See Also

kequate PREp

Examples

Run this code
P<-c(5, 20, 35, 25, 15)
Q<-c(10, 30, 30, 20, 10)
x<-0:4
glmx<-glm(P~I(x)+I(x^2), family="poisson", x=TRUE)
glmy<-glm(Q~I(x)+I(x^2), family="poisson", x=TRUE)
keEG<-kequate("EG", 0:4, 0:4, glmx, glmy)
getEq(keEG)

Run the code above in your browser using DataLab