Learn R Programming

kequate (version 1.5.0)

getH: Retrieve the Continuization Bandwidths

Description

Function to retrieve the bandwidths used in an equating from an object of class keout created by kequate.

Usage

getH(object)

Arguments

object
An object of class keout as created by the function kequate.

Value

A data frame containing the values of h used in the equating.

See Also

kequate

Examples

Run this code
P<-c(5, 20, 35, 25, 15)
Q<-c(10, 30, 30, 20, 10)
x<-0:4
glmx<-glm(P~I(x)+I(x^2), family="poisson", x=TRUE)
glmy<-glm(Q~I(x)+I(x^2), family="poisson", x=TRUE)
keEG<-kequate("EG", 0:4, 0:4, glmx, glmy)
getH(keEG)

Run the code above in your browser using DataLab