cdist-class: Class "cdist"
Description
Stores conditional means, variances, skewnesses and kurtoses of observed and estimated bivariate distributions of test scores.
Objects from the Class
Objects can be created by calls of the form new("cdist", ...). Slots
- est1
- Matrix of conditional means, variances, skewnesses and kurtoses of X given A for the estimated score distribution.
- est2
- Matrix of conditional means, variances, skewnesses and kurtoses of A given X for the estimated score distribution.
- obs1
- Matrix of conditional means, variances, skewnesses and kurtoses of X given A for the observed score distribution.
- obs2
- Matrix of conditional means, variances, skewnesses and kurtoses of A given X for the observed score distribution.
Methods
- plot
signature(x = "keout"): ...