Usage
irtose(design="CE", P, Q, x, y, a=0, qpoints=seq(-6, 6, by=0.1), model="2pl", catsX=0,
catsY=0, catsA=0, see="analytical", replications=50, kernel="gaussian",
h=list(hx=0, hy=0, hxP=0, haP=0, hyQ=0, haQ=0),
hlin=list(hxlin=0, hylin=0, hxPlin=0, haPlin=0, hyQlin=0, haQlin=0), KPEN=0, wpen=0.5,
linear=FALSE, slog=1, bunif=1, altopt=FALSE, wS=0.5, eqcoef="mean-mean", robust=FALSE,
distribution = list("normal", par = data.frame(mu = 0, sigma = 1)))
Arguments
design
A character vector indicating which design to use. Possible designs are EG and CE.
P
Object of class "matrix" or an object created by the R package ltm containing either the responses for each question in group P or the estimated IRT model in group P.
Q
Object of class "matrix" or an object created by the R package ltm containing either the responses for each question in group Q or the estimated IRT model in group Q.
x
Vector of possible score values of the main test X to be equated.
y
Vector of possible score values of the main test Y to be equated.
a
Vector of possible score values of the anchor test A. (For NEAT designs only.)
qpoints
A numeric vector containing the quadrature points used in the equating. If not specified, the quadrature points from the IRT models will be used.
model
A character vector indicating which IRT model to use. Available models are 2pl and 3pl. Default is "2pl".
catsX
The number of category answers for each item on test X. (GPCM and GRM only.)
catsY
The number of category answers for each item on test Y. (GPCM and GRM only.)
catsA
The number of category answers for each item on test A. (GPCM and GRM only.)
see
A character vector indicating which standard errors of equating to use. Options are "analytical" and "bootstrap", with default "analytical".
replications
The number of bootstrap replications if using the bootstrap standard error calculations. Default is 50.
kernel
A character vector indicating which kernel to use, either "gaussian", "logistic", "stdgaussian" or "uniform". Default is "gaussian".
h
Optional argument to specify the continuization parameters manually as a list with suitable bandwidth parameters. In an EG design or a NEAT PSE design: hx and hy, in a NEAT CE design: hxP, haP, hyQ and haQ. (If linear=TRUE, then these arguments have no effect.)
hlin
Optional argument to specify the linear continuization parameters manually as a list with suitable bandwidth parameters. In an EG design or a NEAT PSE design: hxlin and hylin, in a NEAT CE design: hxPlin, haPlin, hyQlin and haQlin.
slog
The parameter used in defining the logistic kernel. Default is 1.
bunif
The parameter used in defining the uniform kernel. Default is 0.5.
KPEN
The constant used in deciding the optimal continuization parameter. Default is 0.
wpen
An argument denoting at which point the derivatives in the second part of the penalty function should be evaluated. Default is 1/4.
linear
Logical denoting if only a linear equating is to be performed. Default is FALSE.
altopt
Logical which sets the bandwidth parameter equal to a variant of Silverman's rule of thumb. Default is FALSE.
wS
The weighting of group P in a PSE equating. Default is 0.5.
eqcoef
Character vector indicating which equating coefficients to use. Options are "mean-mean", "mean-gmean", "mean-sigma", "Stocking-Lord" and "Haebara". Default is "mean-mean". (Only for PSE.)
robust
Logical indicating whether the robust covariance matrix should be calculated for the IRT model. Warning: is slow for large models and large sample sizes. Default is FALSE. (Only for 2pl and GPCM models.)
distribution
A list containing information regarding the latent distribution. Default is the standard normal distribution.